[ wger project ](https://wger.readthedocs.io/en/latest/)
latest  stable  2.4  2.0  1.9
Manual
  * [Using the routines](https://wger.readthedocs.io/en/latest/manual/routines.html)


Installation (prod)
  * [Docker compose](https://wger.readthedocs.io/en/latest/production/docker.html)
  * [Manual installation](https://wger.readthedocs.io/en/latest/production/installation.html)


Development
  * [Backend](https://wger.readthedocs.io/en/latest/development/backend.html)
  * [Frontend](https://wger.readthedocs.io/en/latest/development/frontend.html)
  * [Mobile App](https://wger.readthedocs.io/en/latest/development/mobile_app.html)


Administration
  * [Commands](https://wger.readthedocs.io/en/latest/administration/commands.html)
  * [Settings](https://wger.readthedocs.io/en/latest/administration/settings.html)
  * [Authentication Proxy (SSO)](https://wger.readthedocs.io/en/latest/administration/auth_proxy.html)
  * [Gym administration](https://wger.readthedocs.io/en/latest/administration/gym.html)


API
  * [Using the API](https://wger.readthedocs.io/en/latest/api/api.html)
  * [Using the routine API](https://wger.readthedocs.io/en/latest/api/routines.html)


All the rest
  * [Contributing](https://wger.readthedocs.io/en/latest/contributing.html)
  * [Changelog](https://wger.readthedocs.io/en/latest/changelog.html)


[wger project](https://wger.readthedocs.io/en/latest/)
  * [](https://wger.readthedocs.io/en/latest/)
  * Welcome to the wger 2.5 documentation
  * [ Edit on GitHub](https://github.com/wger-project/docs/blob/master/docs/index.rst)


* * *
# Welcome to the wger 2.5 documentation[](https://wger.readthedocs.io/en/latest/#welcome-to-the-wger-version-documentation "Link to this heading")
[![_images/logo.png](https://wger.readthedocs.io/en/latest/_images/logo.png) ](https://wger.readthedocs.io/en/latest/_images/logo.png)
wger (ˈvɛɡɐ) is a free, open-source web application that helps you manage your personal workouts, weight, and diet plans and can also be used as a simple gym management utility. It offers a REST API as well, for easy integration with other projects and tools.
For more details and a live system, refer to the project’s site: <https://github.com/wger-project>
This documentation is intended for developers and administrators of the software.
## User manual[](https://wger.readthedocs.io/en/latest/#user-manual "Link to this heading")

[Using the routines](https://wger.readthedocs.io/en/latest/manual/routines.html)

How to use the routines and the progression rules
## Installation (production)[](https://wger.readthedocs.io/en/latest/#installation-production "Link to this heading")

[Docker compose](https://wger.readthedocs.io/en/latest/production/docker.html)

Recommended setup to run the application in a production environment, uses Docker and Docker Compose.

[Manual installation](https://wger.readthedocs.io/en/latest/production/installation.html)

“Manual” installation of the application in a production environment.
## Development[](https://wger.readthedocs.io/en/latest/#development "Link to this heading")

[Backend](https://wger.readthedocs.io/en/latest/development/backend.html)

For developers who want to work on the backend / django part of the application (note that this is the main part of the application and also does parts of the frontend)

[Frontend](https://wger.readthedocs.io/en/latest/development/frontend.html)

For developers who want to work on the frontend part of the application

[Mobile App](https://wger.readthedocs.io/en/latest/development/mobile_app.html)

For developers who want to work on the mobile app part of the application
## Administration[](https://wger.readthedocs.io/en/latest/#administration "Link to this heading")

[Commands](https://wger.readthedocs.io/en/latest/administration/commands.html)

Available commands to manage the application and sync exercises and ingredients

[Settings](https://wger.readthedocs.io/en/latest/administration/settings.html)

Available settings for the application

[Authentication Proxy (SSO)](https://wger.readthedocs.io/en/latest/administration/auth_proxy.html)

Alternative authentication settings
## API[](https://wger.readthedocs.io/en/latest/#api "Link to this heading")

[Using the API](https://wger.readthedocs.io/en/latest/api/api.html)

For developers who want to use the API, and it contains information about the API endpoints.

[Using the routine API](https://wger.readthedocs.io/en/latest/api/routines.html)

The data model used for the flexible routines and how to create and read them over the API.
## Contact[](https://wger.readthedocs.io/en/latest/#contact "Link to this heading")
Feel free to contact us if you found this useful or if there was something that didn’t behave as you expected (in this case you can also open a ticket on the issue tracker).
  * **Mastodon:** <https://fosstodon.org/@wger>
  * **Discord:** <https://discord.gg/rPWFv6W>
  * **Issue tracker:** <https://github.com/wger-project/wger/issues>


## Sources[](https://wger.readthedocs.io/en/latest/#sources "Link to this heading")
All the code and the content is freely available and is hosted on GitHub: <https://github.com/wger-project>
## Licence[](https://wger.readthedocs.io/en/latest/#licence "Link to this heading")
The application is licenced under the Affero GNU General Public License 3 or at your choice any later version (AGPL 3+).
The initial exercise and ingredient data is licensed additionally under a Creative Commons Attribution Share-Alike 3.0 (CC-BY-SA 3.0)
The documentation is released under a CC-BY-SA either version 4 of the License, or (at your option) any later version.
Some images were taken from Wikipedia, see the SOURCES file in their respective folders for more details.
[Next ](https://wger.readthedocs.io/en/latest/manual/routines.html "Using the routines")
* * *
© Copyright 2025, Roland Geider.
Built with [Sphinx](https://www.sphinx-doc.org/) using a [theme](https://github.com/readthedocs/sphinx_rtd_theme) provided by [Read the Docs](https://readthedocs.org).
[**GenAI apps + MongoDB Atlas** You don't need a separate database to start building GenAI-powered apps.](https://server.ethicalads.io/proxy/click/10126/019cbbb2-4e9f-76e3-aec8-c147759ded32/)
[Ads by EthicalAds](https://www.ethicalads.io/advertisers/topics/backend-web/?ref=ea-text)
Close Ad
![](https://server.ethicalads.io/proxy/view/10126/019cbbb2-4e9f-76e3-aec8-c147759ded32/)
